';
- print '';
+ print '';
print $langs->trans('DateInvoice');
print ' ';
if ($object->type != Facture::TYPE_CREDIT_NOTE && $action != 'editinvoicedate' && !empty($object->brouillon) && $user->rights->facture->creer) print 'id.'">'.img_edit($langs->trans('SetDate'), 1).' ';
@@ -309,7 +309,7 @@ if ($object->id > 0)
// Payment condition
print '';
- print '';
+ print '';
print $langs->trans('PaymentConditionsShort');
print ' ';
if ($object->type != Facture::TYPE_CREDIT_NOTE && $action != 'editconditions' && !empty($object->brouillon) && $user->rights->facture->creer) print 'id.'">'.img_edit($langs->trans('SetConditions'), 1).' ';
@@ -334,7 +334,7 @@ if ($object->id > 0)
// Date payment term
print '';
- print '';
+ print '';
print $langs->trans('DateMaxPayment');
print ' ';
if ($object->type != Facture::TYPE_CREDIT_NOTE && $action != 'editpaymentterm' && !empty($object->brouillon) && $user->rights->facture->creer) print 'id.'">'.img_edit($langs->trans('SetDate'), 1).' ';
@@ -362,7 +362,7 @@ if ($object->id > 0)
// Payment mode
print '';
- print '';
+ print '';
print $langs->trans('PaymentMode');
print ' ';
if ($action != 'editmode' && !empty($object->brouillon) && $user->rights->facture->creer) print 'id.'">'.img_edit($langs->trans('SetMode'), 1).' ';
@@ -409,7 +409,7 @@ if ($object->id > 0)
print '';
print '
';
- print '
';
+ print '';
if (!empty($conf->multicurrency->enabled) && ($object->multicurrency_code != $conf->currency))
{
diff --git a/htdocs/contrat/card.php b/htdocs/contrat/card.php
index 9342a81395b..bc7e7dc87a9 100644
--- a/htdocs/contrat/card.php
+++ b/htdocs/contrat/card.php
@@ -612,7 +612,7 @@ if (empty($reshook))
$object->generateDocument($object->modelpdf, $outputlangs, $hidedetails, $hidedesc, $hideref);
}
- unset($_POST ['prod_entry_mode']);
+ unset($_POST['prod_entry_mode']);
unset($_POST['qty']);
unset($_POST['type']);
@@ -626,8 +626,8 @@ if (empty($reshook))
unset($_POST['product_desc']);
unset($_POST['fournprice']);
unset($_POST['buying_price']);
- unset($_POST ['np_marginRate']);
- unset($_POST ['np_markRate']);
+ unset($_POST['np_marginRate']);
+ unset($_POST['np_markRate']);
unset($_POST['dp_desc']);
unset($_POST['idprod']);
@@ -1114,6 +1114,7 @@ if ($action == 'create')
if (GETPOST('origin') && GETPOST('originid'))
{
// Parse element/subelement (ex: project_task)
+ $regs = array();
$element = $subelement = GETPOST('origin');
if (preg_match('/^([^_]+)_([^_]+)/i', GETPOST('origin'), $regs))
{
@@ -1544,7 +1545,7 @@ else
$sql .= " cd.date_fin_validite as date_fin, cd.date_cloture as date_fin_reelle,";
$sql .= " cd.commentaire as comment, cd.fk_product_fournisseur_price as fk_fournprice, cd.buy_price_ht as pa_ht,";
$sql .= " cd.fk_unit,";
- $sql .= " p.rowid as pid, p.ref as pref, p.label as plabel, p.fk_product_type as ptype, p.entity as pentity";
+ $sql .= " p.rowid as pid, p.ref as pref, p.label as plabel, p.fk_product_type as ptype, p.entity as pentity, p.tosell, p.tobuy, p.tobatch";
$sql .= " FROM ".MAIN_DB_PREFIX."contratdet as cd";
$sql .= " LEFT JOIN ".MAIN_DB_PREFIX."product as p ON cd.fk_product = p.rowid";
$sql .= " WHERE cd.rowid = ".$object->lines[$cursorline - 1]->id;
@@ -1577,12 +1578,16 @@ else
// Label
if ($objp->fk_product > 0)
{
- print '';
$productstatic->id = $objp->fk_product;
$productstatic->type = $objp->ptype;
$productstatic->ref = $objp->pref;
$productstatic->entity = $objp->pentity;
$productstatic->label = $objp->plabel;
+ $productstatic->status = $objp->tosell;
+ $productstatic->status_buy = $objp->tobuy;
+ $productstatic->status_batch = $objp->tobatch;
+
+ print ' ';
$text = $productstatic->getNomUrl(1, '', 32);
if ($objp->plabel)
{
diff --git a/htdocs/contrat/class/contrat.class.php b/htdocs/contrat/class/contrat.class.php
index ead2e1c816b..7434d886072 100644
--- a/htdocs/contrat/class/contrat.class.php
+++ b/htdocs/contrat/class/contrat.class.php
@@ -1381,10 +1381,10 @@ class Contrat extends CommonObject
/**
* Ajoute une ligne de contrat en base
*
- * @param string $desc Description de la ligne
- * @param float $pu_ht Prix unitaire HT
- * @param int $qty Quantite
- * @param float $txtva Taux tva
+ * @param string $desc Description of line
+ * @param float $pu_ht Unit price net
+ * @param int $qty Quantity
+ * @param float $txtva Vat rate
* @param float $txlocaltax1 Local tax 1 rate
* @param float $txlocaltax2 Local tax 2 rate
* @param int $fk_product Id produit
diff --git a/htdocs/core/actions_massactions.inc.php b/htdocs/core/actions_massactions.inc.php
index 37f2dd62fa3..4a00412f800 100644
--- a/htdocs/core/actions_massactions.inc.php
+++ b/htdocs/core/actions_massactions.inc.php
@@ -352,6 +352,7 @@ if (!$error && $massaction == 'confirm_presend')
{
$langs->load("commercial");
+ $reg = array();
$fromtype = GETPOST('fromtype');
if ($fromtype === 'user') {
$from = $user->getFullName($langs).' <'.$user->email.'>';
diff --git a/htdocs/core/actions_sendmails.inc.php b/htdocs/core/actions_sendmails.inc.php
index 2cd713a5654..0a8ed21da14 100644
--- a/htdocs/core/actions_sendmails.inc.php
+++ b/htdocs/core/actions_sendmails.inc.php
@@ -273,6 +273,7 @@ if (($action == 'send' || $action == 'relance') && !$_POST['addfile'] && !$_POST
$langs->load("commercial");
+ $reg = array();
$fromtype = GETPOST('fromtype', 'alpha');
if ($fromtype === 'robot') {
$from = dol_string_nospecial($conf->global->MAIN_MAIL_EMAIL_FROM, ' ', array(",")).' <'.$conf->global->MAIN_MAIL_EMAIL_FROM.'>';
@@ -292,7 +293,8 @@ if (($action == 'send' || $action == 'relance') && !$_POST['addfile'] && !$_POST
$from = trim($tmp[($reg[1] - 1)]);
}
elseif (preg_match('/senderprofile_(\d+)_(\d+)/', $fromtype, $reg)) {
- $sql = 'SELECT rowid, label, email FROM '.MAIN_DB_PREFIX.'c_email_senderprofile WHERE rowid = '.(int) $reg[1];
+ $sql = 'SELECT rowid, label, email FROM '.MAIN_DB_PREFIX.'c_email_senderprofile';
+ $sql .= ' WHERE rowid = '.(int) $reg[1];
$resql = $db->query($sql);
$obj = $db->fetch_object($resql);
if ($obj)
diff --git a/htdocs/core/class/commonobject.class.php b/htdocs/core/class/commonobject.class.php
index edc84cf2ece..990bfded07f 100644
--- a/htdocs/core/class/commonobject.class.php
+++ b/htdocs/core/class/commonobject.class.php
@@ -4199,6 +4199,7 @@ abstract class CommonObject
$product_static->ref = $line->ref; //can change ref in hook
$product_static->label = $line->label; //can change label in hook
+
$text = $product_static->getNomUrl(1);
// Define output language and label
@@ -7523,7 +7524,10 @@ abstract class CommonObject
}
// If field is an implicit foreign key field
- if (preg_match('/^integer:/i', $this->fields[$key]['type']) && empty($values[$key])) $values[$key] = 'null';
+ if (preg_match('/^integer:/i', $this->fields[$key]['type']) && empty($values[$key])) {
+ if (isset($this->fields[$key]['default'])) $values[$key] = $this->fields[$key]['default'];
+ else $values[$key] = 'null';
+ }
if (!empty($this->fields[$key]['foreignkey']) && empty($values[$key])) $values[$key] = 'null';
}
diff --git a/htdocs/core/class/emailsenderprofile.class.php b/htdocs/core/class/emailsenderprofile.class.php
index 9fbf98fc19c..22a93ab2bbc 100644
--- a/htdocs/core/class/emailsenderprofile.class.php
+++ b/htdocs/core/class/emailsenderprofile.class.php
@@ -20,8 +20,8 @@
*/
/**
- * \file class/emailsenderprofile.class.php
- * \ingroup monmodule
+ * \file core/class/emailsenderprofile.class.php
+ * \ingroup core
* \brief This file is a CRUD class file for EmailSenderProfile (Create/Read/Update/Delete)
*/
@@ -30,6 +30,7 @@ require_once DOL_DOCUMENT_ROOT.'/core/class/commonobject.class.php';
//require_once DOL_DOCUMENT_ROOT . '/societe/class/societe.class.php';
//require_once DOL_DOCUMENT_ROOT . '/product/class/product.class.php';
+
/**
* Class for EmailSenderProfile
*/
@@ -60,24 +61,29 @@ class EmailSenderProfile extends CommonObject
const STATUS_ENABLED = 1;
+
/**
- * 'type' if the field format ('integer', 'integer:Class:pathtoclass', 'varchar(x)', 'double(24,8)', 'text', 'html', 'datetime', 'timestamp', 'float')
+ * 'type' if the field format ('integer', 'integer:ObjectClass:PathToClass[:AddCreateButtonOrNot[:Filter]]', 'varchar(x)', 'double(24,8)', 'real', 'price', 'text', 'html', 'date', 'datetime', 'timestamp', 'duration', 'mail', 'phone', 'url', 'password')
+ * Note: Filter can be a string like "(t.ref:like:'SO-%') or (t.date_creation:<:'20160101') or (t.nature:is:NULL)"
* 'label' the translation key.
* 'enabled' is a condition when the field must be managed.
- * 'visible' says if field is visible in list (Examples: 0=Not visible, 1=Visible on list and create/update/view forms, 2=Visible on list only, 3=Visible on create/update/view form only (not list), 4=Visible on list and update/view form only (not create). Using a negative value means field is not shown by default on list but can be selected for viewing)
- * 'noteditable' says if field is not editable (1 or 0)
+ * 'position' is the sort order of field.
* 'notnull' is set to 1 if not null in database. Set to -1 if we must set data to null if empty ('' or 0).
- * 'default' is a default value for creation (can still be replaced by the global setup of default values)
+ * 'visible' says if field is visible in list (Examples: 0=Not visible, 1=Visible on list and create/update/view forms, 2=Visible on list only, 3=Visible on create/update/view form only (not list), 4=Visible on list and update/view form only (not create). 5=Visible on list and view only (not create/not update). Using a negative value means field is not shown by default on list but can be selected for viewing)
+ * 'noteditable' says if field is not editable (1 or 0)
+ * 'default' is a default value for creation (can still be overwrote by the Setup of Default Values if field is editable in creation form). Note: If default is set to '(PROV)' and field is 'ref', the default value will be set to '(PROVid)' where id is rowid when a new record is created.
* 'index' if we want an index in database.
* 'foreignkey'=>'tablename.field' if the field is a foreign key (it is recommanded to name the field fk_...).
- * 'position' is the sort order of field.
* 'searchall' is 1 if we want to search in this field when making a search from the quick search button.
* 'isameasure' must be set to 1 if you want to have a total on list for this field. Field type must be summable like integer or double(24,8).
* 'css' is the CSS style to use on field. For example: 'maxwidth200'
* 'help' is a string visible as a tooltip on field
- * 'comment' is not used. You can store here any text of your choice. It is not used by application.
* 'showoncombobox' if value of the field must be visible into the label of the combobox that list record
+ * 'disabled' is 1 if we want to have the field locked by a 'disabled' attribute. In most cases, this is never set into the definition of $fields into class, but is set dynamically by some part of code.
* 'arraykeyval' to set list of value if type is a list of predefined values. For example: array("0"=>"Draft","1"=>"Active","-1"=>"Cancel")
+ * 'comment' is not used. You can store here any text of your choice. It is not used by application.
+ *
+ * Note: To have value dynamic, you can set value to 0 in definition and edit the value on the fly into the constructor.
*/
// BEGIN MODULEBUILDER PROPERTIES
@@ -90,8 +96,8 @@ class EmailSenderProfile extends CommonObject
'label' => array('type'=>'varchar(255)', 'label'=>'Label', 'visible'=>1, 'enabled'=>1, 'position'=>30, 'notnull'=>1),
'email' => array('type'=>'varchar(255)', 'label'=>'Email', 'visible'=>1, 'enabled'=>1, 'position'=>40, 'notnull'=>-1),
//'fk_user_creat' => array('type'=>'integer', 'label'=>'UserAuthor', 'visible'=>-1, 'enabled'=>1, 'position'=>500, 'notnull'=>1,),
- //'fk_user_modif' => array('type'=>'integer', 'label'=>'UserModif', 'visible'=>-1, 'enabled'=>1, 'position'=>500, 'notnull'=>-1,),
- 'signature' => array('type'=>'text', 'label'=>'Signature', 'visible'=>-1, 'enabled'=>1, 'position'=>400, 'notnull'=>-1, 'index'=>1,),
+ 'private' => array('type'=>'integer:User:user/class/user.class.php', 'label'=>'User', 'visible'=>-1, 'enabled'=>1, 'position'=>50, 'default'=>'0', 'notnull'=>1),
+ 'signature' => array('type'=>'text', 'label'=>'Signature', 'visible'=>3, 'enabled'=>1, 'position'=>400, 'notnull'=>-1, 'index'=>1,),
'position' => array('type'=>'integer', 'label'=>'Position', 'visible'=>1, 'enabled'=>1, 'position'=>405, 'notnull'=>-1, 'index'=>1,),
'date_creation' => array('type'=>'datetime', 'label'=>'DateCreation', 'visible'=>-1, 'enabled'=>1, 'position'=>500, 'notnull'=>1,),
'tms' => array('type'=>'timestamp', 'label'=>'DateModification', 'visible'=>-1, 'enabled'=>1, 'position'=>500, 'notnull'=>1,),
diff --git a/htdocs/core/class/html.formmail.class.php b/htdocs/core/class/html.formmail.class.php
index 2fd1b409ed7..abad66c8a73 100644
--- a/htdocs/core/class/html.formmail.class.php
+++ b/htdocs/core/class/html.formmail.class.php
@@ -569,7 +569,9 @@ class FormMail extends Form
}
// Add also email aliases from the c_email_senderprofile table
- $sql = 'SELECT rowid, label, email FROM '.MAIN_DB_PREFIX.'c_email_senderprofile WHERE active = 1 ORDER BY position';
+ $sql = 'SELECT rowid, label, email FROM '.MAIN_DB_PREFIX.'c_email_senderprofile';
+ $sql .= ' WHERE active = 1 AND (private = 0 OR private = '.$user->id.')';
+ $sql .= ' ORDER BY position';
$resql = $this->db->query($sql);
if ($resql)
{
diff --git a/htdocs/core/lib/bank.lib.php b/htdocs/core/lib/bank.lib.php
index 0cb6163aa49..6c23e324f71 100644
--- a/htdocs/core/lib/bank.lib.php
+++ b/htdocs/core/lib/bank.lib.php
@@ -172,7 +172,7 @@ function account_statement_prepare_head($object, $num)
$head = array();
$head[$h][0] = DOL_URL_ROOT.'/compta/bank/releve.php?account='.$object->id.'&num='.$num;
- $head[$h][1] = $langs->trans("AccountStatements");
+ $head[$h][1] = $langs->trans("AccountStatement");
$head[$h][2] = 'statement';
$h++;
diff --git a/htdocs/core/lib/files.lib.php b/htdocs/core/lib/files.lib.php
index 9b0fd948c9e..0051d28caf3 100644
--- a/htdocs/core/lib/files.lib.php
+++ b/htdocs/core/lib/files.lib.php
@@ -82,16 +82,16 @@ function dol_dir_list($path, $types = "all", $recursive = 0, $filter = "", $excl
$hookmanager->initHooks(array('fileslib'));
$parameters = array(
- 'path' => $newpath,
- 'types'=> $types,
- 'recursive' => $recursive,
- 'filter' => $filter,
- 'excludefilter' => $excludefilter,
- 'sortcriteria' => $sortcriteria,
- 'sortorder' => $sortorder,
- 'loaddate' => $loaddate,
- 'loadsize' => $loadsize,
- 'mode' => $mode
+ 'path' => $newpath,
+ 'types'=> $types,
+ 'recursive' => $recursive,
+ 'filter' => $filter,
+ 'excludefilter' => $excludefilter,
+ 'sortcriteria' => $sortcriteria,
+ 'sortorder' => $sortorder,
+ 'loaddate' => $loaddate,
+ 'loadsize' => $loadsize,
+ 'mode' => $mode
);
$reshook = $hookmanager->executeHooks('getDirList', $parameters, $object);
}
@@ -146,14 +146,14 @@ function dol_dir_list($path, $types = "all", $recursive = 0, $filter = "", $excl
preg_match('/([^\/]+)\/[^\/]+$/', $path.'/'.$file, $reg);
$level1name = (isset($reg[1]) ? $reg[1] : '');
$file_list[] = array(
- "name" => $file,
- "path" => $path,
- "level1name" => $level1name,
- "relativename" => ($relativename ? $relativename.'/' : '').$file,
- "fullname" => $path.'/'.$file,
- "date" => $filedate,
- "size" => $filesize,
- "type" => 'dir'
+ "name" => $file,
+ "path" => $path,
+ "level1name" => $level1name,
+ "relativename" => ($relativename ? $relativename.'/' : '').$file,
+ "fullname" => $path.'/'.$file,
+ "date" => $filedate,
+ "size" => $filesize,
+ "type" => 'dir'
);
}
}
@@ -179,14 +179,14 @@ function dol_dir_list($path, $types = "all", $recursive = 0, $filter = "", $excl
preg_match('/([^\/]+)\/[^\/]+$/', $path.'/'.$file, $reg);
$level1name = (isset($reg[1]) ? $reg[1] : '');
$file_list[] = array(
- "name" => $file,
- "path" => $path,
- "level1name" => $level1name,
- "relativename" => ($relativename ? $relativename.'/' : '').$file,
- "fullname" => $path.'/'.$file,
- "date" => $filedate,
- "size" => $filesize,
- "type" => 'file'
+ "name" => $file,
+ "path" => $path,
+ "level1name" => $level1name,
+ "relativename" => ($relativename ? $relativename.'/' : '').$file,
+ "fullname" => $path.'/'.$file,
+ "date" => $filedate,
+ "size" => $filesize,
+ "type" => 'file'
);
}
}
@@ -197,7 +197,7 @@ function dol_dir_list($path, $types = "all", $recursive = 0, $filter = "", $excl
// Obtain a list of columns
if (! empty($sortcriteria) && $sortorder)
{
- $file_list = dol_sort_array($file_list, $sortcriteria, ($sortorder == SORT_ASC ? 'asc' : 'desc'));
+ $file_list = dol_sort_array($file_list, $sortcriteria, ($sortorder == SORT_ASC ? 'asc' : 'desc'));
}
}
}
@@ -445,8 +445,8 @@ function dol_is_dir($folder)
*/
function dol_is_dir_empty($dir)
{
- if (!is_readable($dir)) return false;
- return (count(scandir($dir)) == 2);
+ if (!is_readable($dir)) return false;
+ return (count(scandir($dir)) == 2);
}
/**
@@ -514,7 +514,7 @@ function dol_dir_is_emtpy($folder)
else return false;
}
else
- return true; // Dir does not exists
+ return true; // Dir does not exists
}
/**
@@ -624,14 +624,14 @@ function dolReplaceInFile($srcfile, $arrayreplacement, $destfile = '', $newmask
if (empty($arrayreplacementisregex))
{
- $content = make_substitutions($content, $arrayreplacement, null);
+ $content = make_substitutions($content, $arrayreplacement, null);
}
else
{
- foreach ($arrayreplacement as $key => $value)
- {
- $content = preg_replace($key, $value, $content);
- }
+ foreach ($arrayreplacement as $key => $value)
+ {
+ $content = preg_replace($key, $value, $content);
+ }
}
file_put_contents($newpathoftmpdestfile, $content);
@@ -1044,8 +1044,8 @@ function dol_move_uploaded_file($src_file, $dest_file, $allowoverwrite, $disable
$checkvirusarray = dolCheckVirus($src_file);
if (count($checkvirusarray))
{
- dol_syslog('Files.lib::dol_move_uploaded_file File "'.$src_file.'" (target name "'.$dest_file.'") KO with antivirus: errors='.join(',', $checkvirusarray), LOG_WARNING);
- return 'ErrorFileIsInfectedWithAVirus: '.join(',', $checkvirusarray);
+ dol_syslog('Files.lib::dol_move_uploaded_file File "'.$src_file.'" (target name "'.$dest_file.'") KO with antivirus: errors='.join(',', $checkvirusarray), LOG_WARNING);
+ return 'ErrorFileIsInfectedWithAVirus: '.join(',', $checkvirusarray);
}
}
@@ -1141,7 +1141,7 @@ function dol_delete_file($file, $disableglob = 0, $nophperrors = 0, $nohook = 0,
global $hookmanager;
// Load translation files required by the page
- $langs->loadLangs(array('other', 'errors'));
+ $langs->loadLangs(array('other', 'errors'));
dol_syslog("dol_delete_file file=".$file." disableglob=".$disableglob." nophperrors=".$nophperrors." nohook=".$nohook);
@@ -1158,10 +1158,10 @@ function dol_delete_file($file, $disableglob = 0, $nophperrors = 0, $nohook = 0,
$hookmanager->initHooks(array('fileslib'));
$parameters = array(
- 'GET' => $_GET,
- 'file' => $file,
- 'disableglob'=> $disableglob,
- 'nophperrors' => $nophperrors
+ 'GET' => $_GET,
+ 'file' => $file,
+ 'disableglob'=> $disableglob,
+ 'nophperrors' => $nophperrors
);
$reshook = $hookmanager->executeHooks('deleteFile', $parameters, $object);
}
@@ -1458,9 +1458,9 @@ function dol_meta_create($object)
fputs($fp, $meta);
fclose($fp);
if (!empty($conf->global->MAIN_UMASK))
- @chmod($file, octdec($conf->global->MAIN_UMASK));
+ @chmod($file, octdec($conf->global->MAIN_UMASK));
- return 1;
+ return 1;
}
else
{
@@ -1830,19 +1830,19 @@ function dol_convert_file($fileinput, $ext = 'png', $fileoutput = '', $page = ''
global $langs;
if (class_exists('Imagick'))
{
- $image = new Imagick();
+ $image = new Imagick();
try {
- $filetoconvert = $fileinput.(($page != '') ? '['.$page.']' : '');
- //var_dump($filetoconvert);
- $ret = $image->readImage($filetoconvert);
+ $filetoconvert = $fileinput.(($page != '') ? '['.$page.']' : '');
+ //var_dump($filetoconvert);
+ $ret = $image->readImage($filetoconvert);
} catch (Exception $e) {
- $ext = pathinfo($fileinput, PATHINFO_EXTENSION);
- dol_syslog("Failed to read image using Imagick (Try to install package 'apt-get install php-imagick ghostscript' and check there is no policy to disable ".$ext." convertion in /etc/ImageMagick*/policy.xml): ".$e->getMessage(), LOG_WARNING);
+ $ext = pathinfo($fileinput, PATHINFO_EXTENSION);
+ dol_syslog("Failed to read image using Imagick (Try to install package 'apt-get install php-imagick ghostscript' and check there is no policy to disable ".$ext." convertion in /etc/ImageMagick*/policy.xml): ".$e->getMessage(), LOG_WARNING);
return 0;
}
if ($ret)
{
- $ret = $image->setImageFormat($ext);
+ $ret = $image->setImageFormat($ext);
if ($ret)
{
if (empty($fileoutput)) $fileoutput=$fileinput.".".$ext;
@@ -1850,13 +1850,13 @@ function dol_convert_file($fileinput, $ext = 'png', $fileoutput = '', $page = ''
$count = $image->getNumberImages();
if (! dol_is_file($fileoutput) || is_writeable($fileoutput))
{
- try {
+ try {
$ret = $image->writeImages($fileoutput, true);
- }
- catch(Exception $e)
- {
- dol_syslog($e->getMessage(), LOG_WARNING);
- }
+ }
+ catch(Exception $e)
+ {
+ dol_syslog($e->getMessage(), LOG_WARNING);
+ }
}
else
{
@@ -2106,16 +2106,16 @@ function dol_compress_dir($inputdir, $outputfile, $mode = "zip", $excludefiles =
elseif ($mode == 'zip')
{
/*if (defined('ODTPHP_PATHTOPCLZIP'))
- {
- $foundhandler=0; // TODO implement this
+ {
+ $foundhandler=0; // TODO implement this
- include_once ODTPHP_PATHTOPCLZIP.'/pclzip.lib.php';
- $archive = new PclZip($outputfile);
- $archive->add($inputfile, PCLZIP_OPT_REMOVE_PATH, dirname($inputfile));
- //$archive->add($inputfile);
- return 1;
- }
- else*/
+ include_once ODTPHP_PATHTOPCLZIP.'/pclzip.lib.php';
+ $archive = new PclZip($outputfile);
+ $archive->add($inputfile, PCLZIP_OPT_REMOVE_PATH, dirname($inputfile));
+ //$archive->add($inputfile);
+ return 1;
+ }
+ else*/
//if (class_exists('ZipArchive') && ! empty($conf->global->MAIN_USE_ZIPARCHIVE_FOR_ZIP_COMPRESS))
if (class_exists('ZipArchive'))
{
@@ -2532,14 +2532,14 @@ function dol_check_secure_access_document($modulepart, $original_file, $entity,
}
$original_file=$conf->commande->multidir_output[$entity].'/temp/massgeneration/'.$user->id.'/'.$original_file;
}
- elseif ($modulepart == 'massfilesarea_sendings')
- {
- if ($fuser->rights->expedition->{$lire} || preg_match('/^specimen/i', $original_file))
- {
- $accessallowed=1;
- }
- $original_file=$conf->expedition->dir_output.'/sending/temp/massgeneration/'.$user->id.'/'.$original_file;
- }
+ elseif ($modulepart == 'massfilesarea_sendings')
+ {
+ if ($fuser->rights->expedition->{$lire} || preg_match('/^specimen/i', $original_file))
+ {
+ $accessallowed=1;
+ }
+ $original_file=$conf->expedition->dir_output.'/sending/temp/massgeneration/'.$user->id.'/'.$original_file;
+ }
elseif ($modulepart == 'massfilesarea_invoices')
{
if ($fuser->rights->facture->{$lire} || preg_match('/^specimen/i', $original_file))
@@ -2963,18 +2963,21 @@ function dol_check_secure_access_document($modulepart, $original_file, $entity,
exit;
}
- $perm = GETPOST('perm');
- $subperm = GETPOST('subperm');
- if ($perm || $subperm)
- {
- if (($perm && !$subperm && $fuser->rights->$modulepart->$perm) || ($perm && $subperm && $fuser->rights->$modulepart->$perm->$subperm)) $accessallowed = 1;
- $original_file = $conf->$modulepart->dir_output.'/'.$original_file;
- }
- else
- {
- if ($fuser->rights->$modulepart->{$lire} || $fuser->rights->$modulepart->{$read}) $accessallowed = 1;
- $original_file = $conf->$modulepart->dir_output.'/'.$original_file;
- }
+ /*$perm = GETPOST('perm', 'aZ09');
+ $subperm = GETPOST('subperm', 'aZ09');
+ if ($perm || $subperm)
+ {
+ if (($perm && !$subperm && $fuser->rights->$modulepart->$perm) || ($perm && $subperm && $fuser->rights->$modulepart->$perm->$subperm)) $accessallowed = 1;
+ }
+ else
+ {*/
+ // Check fuser->rights->modulepart->myobject->read and fuser->rights->modulepart->read
+ $partsofdirinoriginalfile = explode('/', $original_file);
+ $partofdirinoriginalfile = $partsofdirinoriginalfile[0];
+ if ($partofdirinoriginalfile && ($fuser->rights->$modulepart->$partofdirinoriginalfile->{$lire} || $fuser->rights->$modulepart->$partofdirinoriginalfile->{$read})) $accessallowed = 1;
+ if ($fuser->rights->$modulepart->{$lire} || $fuser->rights->$modulepart->{$read}) $accessallowed = 1;
+ //}
+ $original_file = $conf->$modulepart->dir_output.'/'.$original_file;
}
// For modules who wants to manage different levels of permissions for documents
diff --git a/htdocs/core/lib/functions.lib.php b/htdocs/core/lib/functions.lib.php
index 8805da44a96..3d27653149a 100644
--- a/htdocs/core/lib/functions.lib.php
+++ b/htdocs/core/lib/functions.lib.php
@@ -3060,7 +3060,7 @@ function img_picto($titlealt, $picto, $moreatt = '', $pictoisfullpath = false, $
//if (in_array($picto, array('switch_off', 'switch_on', 'off', 'on')))
if (empty($srconly) && in_array($pictowithouttext, array(
'1downarrow', '1uparrow', '1leftarrow', '1rightarrow', '1uparrow_selected', '1downarrow_selected', '1leftarrow_selected', '1rightarrow_selected',
- 'address', 'bank', 'bookmark', 'building', 'cash-register', 'close_title', 'cubes', 'delete', 'dolly', 'edit', 'ellipsis-h',
+ 'address', 'barcode', 'bank', 'bookmark', 'building', 'cash-register', 'close_title', 'cubes', 'delete', 'dolly', 'edit', 'ellipsis-h',
'filter', 'file-code', 'grip', 'grip_title', 'list', 'listlight', 'note',
'object_bookmark', 'object_list', 'object_calendar', 'object_calendarweek', 'object_calendarmonth', 'object_calendarday', 'object_calendarperuser',
'off', 'on', 'play', 'playdisabled', 'printer', 'resize', 'stats',
diff --git a/htdocs/core/tpl/objectline_view.tpl.php b/htdocs/core/tpl/objectline_view.tpl.php
index 408a2a6f5b2..19a10e0f560 100644
--- a/htdocs/core/tpl/objectline_view.tpl.php
+++ b/htdocs/core/tpl/objectline_view.tpl.php
@@ -66,11 +66,11 @@ $domData .= ' data-product_type="'.$line->product_type.'"';
$coldisplay = 0; ?>
- >
+ >
global->MAIN_VIEW_LINE_NUMBER)) { ?>
-
+
-
+
info_bits & 2) == 2) {
print '';
@@ -88,32 +88,32 @@ if (($line->info_bits & 2) == 2) {
{
$discount = new DiscountAbsolute($this->db);
$discount->fetch($line->fk_remise_except);
- echo ($txt ? ' - ' : '').$langs->transnoentities("DiscountFromCreditNote", $discount->getNomUrl(0));
+ print ($txt ? ' - ' : '').$langs->transnoentities("DiscountFromCreditNote", $discount->getNomUrl(0));
}
elseif ($line->description == '(DEPOSIT)' && $line->fk_remise_except > 0)
{
$discount = new DiscountAbsolute($this->db);
$discount->fetch($line->fk_remise_except);
- echo ($txt ? ' - ' : '').$langs->transnoentities("DiscountFromDeposit", $discount->getNomUrl(0));
+ print ($txt ? ' - ' : '').$langs->transnoentities("DiscountFromDeposit", $discount->getNomUrl(0));
// Add date of deposit
if (!empty($conf->global->INVOICE_ADD_DEPOSIT_DATE))
- echo ' ('.dol_print_date($discount->datec).')';
+ print ' ('.dol_print_date($discount->datec).')';
}
elseif ($line->description == '(EXCESS RECEIVED)' && $objp->fk_remise_except > 0)
{
$discount = new DiscountAbsolute($this->db);
$discount->fetch($line->fk_remise_except);
- echo ($txt ? ' - ' : '').$langs->transnoentities("DiscountFromExcessReceived", $discount->getNomUrl(0));
+ print ($txt ? ' - ' : '').$langs->transnoentities("DiscountFromExcessReceived", $discount->getNomUrl(0));
}
elseif ($line->description == '(EXCESS PAID)' && $objp->fk_remise_except > 0)
{
$discount = new DiscountAbsolute($this->db);
$discount->fetch($line->fk_remise_except);
- echo ($txt ? ' - ' : '').$langs->transnoentities("DiscountFromExcessPaid", $discount->getNomUrl(0));
+ print ($txt ? ' - ' : '').$langs->transnoentities("DiscountFromExcessPaid", $discount->getNomUrl(0));
}
else
{
- echo ($txt ? ' - ' : '').dol_htmlentitiesbr($line->description);
+ print ($txt ? ' - ' : '').dol_htmlentitiesbr($line->description);
}
}
}
@@ -123,7 +123,7 @@ else
if ($line->fk_product > 0)
{
- echo $form->textwithtooltip($text, $description, 3, '', '', $i, 0, (!empty($line->fk_parent_line) ?img_picto('', 'rightarrow') : ''));
+ print $form->textwithtooltip($text, $description, 3, '', '', $i, 0, (!empty($line->fk_parent_line) ?img_picto('', 'rightarrow') : ''));
}
else
{
@@ -132,30 +132,30 @@ else
if (!empty($line->label)) {
$text .= ' '.$line->label.' ';
- echo $form->textwithtooltip($text, dol_htmlentitiesbr($line->description), 3, '', '', $i, 0, (!empty($line->fk_parent_line) ?img_picto('', 'rightarrow') : ''));
+ print $form->textwithtooltip($text, dol_htmlentitiesbr($line->description), 3, '', '', $i, 0, (!empty($line->fk_parent_line) ?img_picto('', 'rightarrow') : ''));
} else {
- if (!empty($line->fk_parent_line)) echo img_picto('', 'rightarrow');
+ if (!empty($line->fk_parent_line)) print img_picto('', 'rightarrow');
if (preg_match('/^\(DEPOSIT\)/', $line->description)) {
$newdesc = preg_replace('/^\(DEPOSIT\)/', $langs->trans("Deposit"), $line->description);
- echo $text.' '.dol_htmlentitiesbr($newdesc);
+ print $text.' '.dol_htmlentitiesbr($newdesc);
}
else {
- echo $text.' '.dol_htmlentitiesbr($line->description);
+ print $text.' '.dol_htmlentitiesbr($line->description);
}
}
}
// Show date range
if ($line->element == 'facturedetrec') {
- if ($line->date_start_fill || $line->date_end_fill) echo '';
- if ($line->date_start_fill) echo $langs->trans('AutoFillDateFromShort').': '.yn($line->date_start_fill);
- if ($line->date_start_fill && $line->date_end_fill) echo ' - ';
- if ($line->date_end_fill) echo $langs->trans('AutoFillDateToShort').': '.yn($line->date_end_fill);
- if ($line->date_start_fill || $line->date_end_fill) echo '
';
+ if ($line->date_start_fill || $line->date_end_fill) print '';
+ if ($line->date_start_fill) print $langs->trans('AutoFillDateFromShort').': '.yn($line->date_start_fill);
+ if ($line->date_start_fill && $line->date_end_fill) print ' - ';
+ if ($line->date_end_fill) print $langs->trans('AutoFillDateToShort').': '.yn($line->date_end_fill);
+ if ($line->date_start_fill || $line->date_end_fill) print '
';
}
else {
- if ($line->date_start || $line->date_end) echo ''.get_date_range($line->date_start, $line->date_end, $format).'
';
- //echo get_date_range($line->date_start, $line->date_end, $format);
+ if ($line->date_start || $line->date_end) print ''.get_date_range($line->date_start, $line->date_end, $format).'
';
+ //print get_date_range($line->date_start, $line->date_end, $format);
}
// Add description in form
@@ -170,15 +170,16 @@ if ($user->rights->fournisseur->lire && $line->fk_fournprice > 0)
require_once DOL_DOCUMENT_ROOT.'/fourn/class/fournisseur.product.class.php';
$productfourn = new ProductFournisseur($this->db);
$productfourn->fetch_product_fournisseur_price($line->fk_fournprice);
- echo '
'.$langs->trans('Supplier').' : '.$productfourn->getSocNomUrl(1, 'supplier').' - '.$langs->trans('Ref').' : ';
+ print '
';
+ print ''.$langs->trans('Supplier').' : '.$productfourn->getSocNomUrl(1, 'supplier').' - '.$langs->trans('Ref').' : ';
// Supplier ref
if ($user->rights->produit->creer || $user->rights->service->creer) // change required right here
{
- echo $productfourn->getNomUrl();
+ print $productfourn->getNomUrl();
}
else
{
- echo $productfourn->ref_supplier;
+ print $productfourn->ref_supplier;
}
}
@@ -186,14 +187,14 @@ if (!empty($conf->accounting->enabled) && $line->fk_accounting_account > 0)
{
$accountingaccount = new AccountingAccount($this->db);
$accountingaccount->fetch($line->fk_accounting_account);
- echo '
'.$langs->trans('AccountingAffectation').' : '.$accountingaccount->getNomUrl(0, 1, 1);
+ print '
'.$langs->trans('AccountingAffectation').' : '.$accountingaccount->getNomUrl(0, 1, 1);
}
print ' ';
if ($object->element == 'supplier_proposal' || $object->element == 'order_supplier' || $object->element == 'invoice_supplier') // We must have same test in printObjectLines
{
print '';
- echo ($line->ref_fourn ? $line->ref_fourn : $line->ref_supplier);
+ print ($line->ref_fourn ? $line->ref_fourn : $line->ref_supplier);
print ' ';
}
// VAT Rate
@@ -204,18 +205,18 @@ if (price2num($line->tva_tx)) $positiverates .= ($positiverates ? '/' :
if (price2num($line->total_localtax1)) $positiverates .= ($positiverates ? '/' : '').price2num($line->localtax1_tx);
if (price2num($line->total_localtax2)) $positiverates .= ($positiverates ? '/' : '').price2num($line->localtax2_tx);
if (empty($positiverates)) $positiverates = '0';
-echo vatrate($positiverates.($line->vat_src_code ? ' ('.$line->vat_src_code.')' : ''), '%', $line->info_bits);
-//echo vatrate($line->tva_tx.($line->vat_src_code?(' ('.$line->vat_src_code.')'):''), '%', $line->info_bits);
+print vatrate($positiverates.($line->vat_src_code ? ' ('.$line->vat_src_code.')' : ''), '%', $line->info_bits);
+//print vatrate($line->tva_tx.($line->vat_src_code?(' ('.$line->vat_src_code.')'):''), '%', $line->info_bits);
?>
- subprice); ?>
+ subprice); ?>
multicurrency->enabled) && $this->multicurrency_code != $conf->currency) { ?>
- multicurrency_subprice); ?>
+ multicurrency_subprice); ?>
- pu_ttc) ?price($line->pu_ttc) : price($line->subprice)); ?>
+ pu_ttc) ?price($line->pu_ttc) : price($line->subprice)); ?>
@@ -225,8 +226,8 @@ if ((($line->info_bits & 2) != 2) && $line->special_code != 3) {
// for example always visible on invoice but must be visible only if stock module on and stock decrease option is on invoice validation and status is not validated
// must also not be output for most entities (proposal, intervention, ...)
//if($line->qty > $line->stock) print img_picto($langs->trans("StockTooLow"),"warning", 'style="vertical-align: bottom;"')." ";
- echo price($line->qty, 0, '', 0, 0); // Yes, it is a quantity, not a price, but we just want the formating role of function price
-} else echo ' ';
+ print price($line->qty, 0, '', 0, 0); // Yes, it is a quantity, not a price, but we just want the formating role of function price
+} else print ' ';
print ' ';
if ($conf->global->PRODUCT_USE_UNITS)
@@ -242,7 +243,7 @@ if (!empty($line->remise_percent) && $line->special_code != 3) {
print '';
$coldisplay++;
include_once DOL_DOCUMENT_ROOT.'/core/lib/functions2.lib.php';
- echo dol_print_reduction($line->remise_percent, $langs);
+ print dol_print_reduction($line->remise_percent, $langs);
print ' ';
} else {
print ' ';
@@ -264,17 +265,17 @@ if ($this->situation_cycle_ref)
if ($usemargins && !empty($conf->margin->enabled) && empty($user->socid))
{
if (!empty($user->rights->margins->creer)) { ?>
- pa_ht); ?>
+ pa_ht); ?>
global->DISPLAY_MARGIN_RATES) && $user->rights->margins->liretous) { ?>
- pa_ht == 0) ? 'n/a' : price(price2num($line->marge_tx, 'MT')).'%'); ?>
+ pa_ht == 0) ? 'n/a' : price(price2num($line->marge_tx, 'MT')).'%'); ?>
global->DISPLAY_MARK_RATES) && $user->rights->margins->liretous) {?>
- marque_tx, 'MT')).'%'; ?>
+ marque_tx, 'MT')).'%'; ?>
special_code == 3) { ?>
- trans('Option'); ?>
+ trans('Option'); ?>
';
$coldisplay++;
@@ -309,8 +310,8 @@ if ($this->statut == 0 && ($object_rights->creer) && $action != 'selectlines') {
$coldisplay++;
if (($line->info_bits & 2) == 2 || !empty($disableedit)) {
} else { ?>
- id.'&action=editline&lineid='.$line->id.'#line_'.$line->id; ?>">
- ';
+ id.'&action=editline&lineid='.$line->id.'#line_'.$line->id; ?>">
+ ';
}
print '';
@@ -327,13 +328,13 @@ if ($this->statut == 0 && ($object_rights->creer) && $action != 'selectlines') {
print ' ';
$coldisplay++;
if ($i > 0) { ?>
- id.'&action=up&rowid='.$line->id; ?>">
-
+ id.'&action=up&rowid='.$line->id; ?>">
+
- id.'&action=down&rowid='.$line->id; ?>">
-
+ id.'&action=down&rowid='.$line->id; ?>">
+
';
@@ -347,7 +348,7 @@ if ($this->statut == 0 && ($object_rights->creer) && $action != 'selectlines') {
}
if ($action == 'selectlines') { ?>
-
+
\n";
diff --git a/htdocs/install/mysql/tables/llx_c_email_senderprofile.sql b/htdocs/install/mysql/tables/llx_c_email_senderprofile.sql
index 3bc69695f5d..cd81eb4c42a 100644
--- a/htdocs/install/mysql/tables/llx_c_email_senderprofile.sql
+++ b/htdocs/install/mysql/tables/llx_c_email_senderprofile.sql
@@ -1,5 +1,5 @@
-- ===================================================================
--- Copyright (C) 2001-2017 Laurent Destailleur
+-- Copyright (C) 2001-2019 Laurent Destailleur
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@ create table llx_c_email_senderprofile
(
rowid integer AUTO_INCREMENT PRIMARY KEY,
entity integer DEFAULT 1 NOT NULL, -- multi company id
- private smallint DEFAULT 0 NOT NULL, -- Template public or private
+ private smallint DEFAULT 0 NOT NULL, -- Template public (0) or private (id of user)
date_creation datetime,
tms timestamp,
label varchar(255), -- Label of predefined email
diff --git a/htdocs/install/mysql/tables/llx_inventorydet.sql b/htdocs/install/mysql/tables/llx_inventorydet.sql
index 1a2b63a9252..c70a2909882 100644
--- a/htdocs/install/mysql/tables/llx_inventorydet.sql
+++ b/htdocs/install/mysql/tables/llx_inventorydet.sql
@@ -26,8 +26,8 @@ fk_inventory integer DEFAULT 0,
fk_warehouse integer DEFAULT 0,
fk_product integer DEFAULT 0,
batch varchar(30) DEFAULT NULL, -- Lot or serial number
-qty_view double DEFAULT NULL, -- must be filled once regulation is done
-qty_stock double DEFAULT NULL, -- can be filled during draft edition
+qty_stock double DEFAULT NULL, -- The targeted value. can be filled during draft edition
+qty_view double DEFAULT NULL, -- must be filled once regulation is done
qty_regulated double DEFAULT NULL -- must be filled once regulation is done
)
ENGINE=InnoDB;
diff --git a/htdocs/install/upgrade2.php b/htdocs/install/upgrade2.php
index 4d29f03003e..12d9ef9b734 100644
--- a/htdocs/install/upgrade2.php
+++ b/htdocs/install/upgrade2.php
@@ -484,6 +484,7 @@ if (!GETPOST('action', 'aZ09') || preg_match('/upgrade/i', GETPOST('action', 'aZ
'MAIN_MODULE_PAYBOX'=>'newboxdefonly',
'MAIN_MODULE_PRINTING'=>'newboxdefonly',
'MAIN_MODULE_PRODUIT'=>'newboxdefonly',
+ 'MAIN_MODULE_RESOURCE'=>'newboxdefonly',
'MAIN_MODULE_SALARIES'=>'newboxdefonly',
'MAIN_MODULE_SYSLOG'=>'newboxdefonly',
'MAIN_MODULE_SOCIETE'=>'newboxdefonly',
diff --git a/htdocs/langs/en_US/stocks.lang b/htdocs/langs/en_US/stocks.lang
index fb3806cc0ef..9856649b834 100644
--- a/htdocs/langs/en_US/stocks.lang
+++ b/htdocs/langs/en_US/stocks.lang
@@ -193,6 +193,7 @@ TheoricalQty=Theorique qty
TheoricalValue=Theorique qty
LastPA=Last BP
CurrentPA=Curent BP
+RecordedQty=Recorded Qty
RealQty=Real Qty
RealValue=Real Value
RegulatedQty=Regulated Qty
diff --git a/htdocs/modulebuilder/template/class/myobject.class.php b/htdocs/modulebuilder/template/class/myobject.class.php
index 0c0b7230b0b..7209738fa60 100644
--- a/htdocs/modulebuilder/template/class/myobject.class.php
+++ b/htdocs/modulebuilder/template/class/myobject.class.php
@@ -732,6 +732,9 @@ class MyObject extends CommonObject
$label = ''.$langs->trans("MyObject").' ';
$label .= ' ';
$label .= ''.$langs->trans('Ref').': '.$this->ref;
+ if (isset($this->status)) {
+ $label.= '' . $langs->trans("Status").": ".$this->getLibStatut(5);
+ }
$url = dol_buildpath('/mymodule/myobject_card.php', 1).'?id='.$this->id;
diff --git a/htdocs/modulebuilder/template/myobject_list.php b/htdocs/modulebuilder/template/myobject_list.php
index 09c90aba987..13f359f43cc 100644
--- a/htdocs/modulebuilder/template/myobject_list.php
+++ b/htdocs/modulebuilder/template/myobject_list.php
@@ -82,7 +82,7 @@ $optioncss = GETPOST('optioncss', 'aZ'); // Option for the css output (always '
$id = GETPOST('id', 'int');
// Load variable for pagination
-$limit = GETPOST('limit', 'int') ?GETPOST('limit', 'int') : $conf->liste_limit;
+$limit = GETPOST('limit', 'int') ? GETPOST('limit', 'int') : $conf->liste_limit;
$sortfield = GETPOST('sortfield', 'alpha');
$sortorder = GETPOST('sortorder', 'alpha');
$page = GETPOST('page', 'int');
@@ -137,7 +137,7 @@ $arrayfields=array();
foreach($object->fields as $key => $val)
{
// If $val['visible']==0, then we never show the field
- if (!empty($val['visible'])) $arrayfields['t.'.$key]=array('label'=>$val['label'], 'checked'=>(($val['visible']<0)?0:1), 'enabled'=>($val['enabled'] && ($val['visible'] != 3)), 'position'=>$val['position']);
+ if (!empty($val['visible'])) $arrayfields['t.'.$key] = array('label'=>$val['label'], 'checked'=>(($val['visible'] < 0) ? 0 : 1), 'enabled'=>($val['enabled'] && ($val['visible'] != 3)), 'position'=>$val['position']);
}
// Extra fields
if (is_array($extrafields->attributes[$object->table_element]['label']) && count($extrafields->attributes[$object->table_element]['label']) > 0)
diff --git a/htdocs/mrp/class/mo.class.php b/htdocs/mrp/class/mo.class.php
index b22e7e41b95..d3845ed412b 100644
--- a/htdocs/mrp/class/mo.class.php
+++ b/htdocs/mrp/class/mo.class.php
@@ -964,6 +964,9 @@ class Mo extends CommonObject
$label = ''.$langs->trans("MO").' ';
$label .= ' ';
$label .= ''.$langs->trans('Ref').': '.$this->ref;
+ if (isset($this->status)) {
+ $label.= '' . $langs->trans("Status").": ".$this->getLibStatut(5);
+ }
$url = dol_buildpath('/mrp/mo_card.php', 1).'?id='.$this->id;
diff --git a/htdocs/opensurvey/index.php b/htdocs/opensurvey/index.php
index 92bcd788ad6..53f45e75dcf 100644
--- a/htdocs/opensurvey/index.php
+++ b/htdocs/opensurvey/index.php
@@ -59,7 +59,7 @@ else dol_print_error($db, '');
$title = $langs->trans("OpenSurveyArea");
llxHeader('', $title);
-print load_fiche_titre($title, '', 'wrench');
+print load_fiche_titre($title, '', 'generic');
print '';
diff --git a/htdocs/product/class/product.class.php b/htdocs/product/class/product.class.php
index ba143057b59..8ba85869a4f 100644
--- a/htdocs/product/class/product.class.php
+++ b/htdocs/product/class/product.class.php
@@ -4240,10 +4240,7 @@ class Product extends CommonObject
$label .= "
".$langs->trans("ManageLotSerial").' : '.$this->getLibStatut(0, 2);
}
}
- //if ($this->type == Product::TYPE_SERVICE)
- //{
- //
- //}
+
if (!empty($conf->accounting->enabled) && $this->status) {
include_once DOL_DOCUMENT_ROOT.'/core/lib/accounting.lib.php';
$label .= '
'.$langs->trans('ProductAccountancySellCode').': '.length_accountg($this->accountancy_code_sell);
@@ -4256,6 +4253,11 @@ class Product extends CommonObject
include_once DOL_DOCUMENT_ROOT.'/core/lib/accounting.lib.php';
$label .= '
'.$langs->trans('ProductAccountancyBuyCode').': '.length_accountg($this->accountancy_code_buy);
}
+ if (isset($this->status) && isset($this->status_buy)) {
+ $label.= '
' . $langs->trans("Status").": ".$this->getLibStatut(5, 0);
+ $label.= ' '.$this->getLibStatut(5, 1);
+ }
+
if (!empty($this->entity)) {
$tmpphoto = $this->show_photos('product', $conf->product->multidir_output[$this->entity], 1, 1, 0, 0, 0, 80);
if ($this->nbphoto > 0) { $label .= '
'.$tmpphoto;
diff --git a/htdocs/product/index.php b/htdocs/product/index.php
index 55244f31e52..d885b36a877 100644
--- a/htdocs/product/index.php
+++ b/htdocs/product/index.php
@@ -312,6 +312,15 @@ if ($result)
{
$objp = $db->fetch_object($result);
+ $product_static->id = $objp->rowid;
+ $product_static->ref = $objp->ref;
+ $product_static->label = $objp->label;
+ $product_static->type = $objp->fk_product_type;
+ $product_static->entity = $objp->entity;
+ $product_static->status = $objp->tosell;
+ $product_static->status_buy = $objp->tobuy;
+ $product_static->status_batch = $objp->tobatch;
+
//Multilangs
if (!empty($conf->global->MAIN_MULTILANGS))
{
@@ -331,12 +340,6 @@ if ($result)
print '
';
print '';
- $product_static->id = $objp->rowid;
- $product_static->ref = $objp->ref;
- $product_static->label = $objp->label;
- $product_static->type = $objp->fk_product_type;
- $product_static->entity = $objp->entity;
- $product_static->status_batch = $objp->tobatch;
print $product_static->getNomUrl(1, '', 16);
print " \n";
print ''.dol_trunc($objp->label, 32).' ';
diff --git a/htdocs/product/inventory/card.php b/htdocs/product/inventory/card.php
index 305c586d82c..0c913834738 100644
--- a/htdocs/product/inventory/card.php
+++ b/htdocs/product/inventory/card.php
@@ -302,7 +302,7 @@ if ($object->id > 0 && (empty($action) || ($action != 'edit' && $action != 'crea
print '';
print '
';
print '
';
- print '
'."\n";
+ print ''."\n";
// Common attributes
include DOL_DOCUMENT_ROOT.'/core/tpl/commonfields_view.tpl.php';
diff --git a/htdocs/product/inventory/class/inventory.class.php b/htdocs/product/inventory/class/inventory.class.php
index 207698e6a3f..f63cbe30017 100644
--- a/htdocs/product/inventory/class/inventory.class.php
+++ b/htdocs/product/inventory/class/inventory.class.php
@@ -124,6 +124,11 @@ class Inventory extends CommonObject
*/
public $fk_warehouse;
+ /**
+ * @var int ID
+ */
+ public $fk_product;
+
public $date_inventory;
public $title;
diff --git a/htdocs/product/inventory/inventory.php b/htdocs/product/inventory/inventory.php
index daf35ad7f95..f43f1fc3b1c 100644
--- a/htdocs/product/inventory/inventory.php
+++ b/htdocs/product/inventory/inventory.php
@@ -101,13 +101,7 @@ if (empty($reshook))
$error = 0;
$backurlforlist = DOL_URL_ROOT.'/product/inventory/list.php';
-
- if (empty($backtopage) || ($cancel && empty($id))) {
- //var_dump($backurlforlist);exit;
- if (empty($id) && (($action != 'add' && $action != 'create') || $cancel)) $backtopage = $backurlforlist;
- else $backtopage = DOL_URL_ROOT.'/bom/bom_card.php?id='.($id > 0 ? $id : '__ID__');
- }
-
+ $backtopage = DOL_URL_ROOT.'/product/inventory/inventory.php?id='.$object->id;
// Actions cancel, add, update, delete or clone
include DOL_DOCUMENT_ROOT.'/core/actions_addupdatedelete.inc.php';
@@ -153,7 +147,7 @@ jQuery(document).ready(function() {
// Part to show record
-if ($object->id > 0 && (empty($action) || ($action != 'edit' && $action != 'create')))
+if ($object->id > 0)
{
$res = $object->fetch_optionals();
@@ -242,7 +236,7 @@ if ($object->id > 0 && (empty($action) || ($action != 'edit' && $action != 'crea
print '';
print '
';
print '
';
- print '
'."\n";
+ print ''."\n";
// Common attributes
include DOL_DOCUMENT_ROOT.'/core/tpl/commonfields_view.tpl.php';
@@ -260,7 +254,22 @@ if ($object->id > 0 && (empty($action) || ($action != 'edit' && $action != 'crea
// Buttons for actions
- if ($action != 'presend' && $action != 'editline') {
+ if ($action == 'edit') {
+ print '';
+ }
}
// End of page
diff --git a/htdocs/product/inventory/tpl/inventory.tpl.php b/htdocs/product/inventory/tpl/inventory.tpl.php
deleted file mode 100644
index 992557505db..00000000000
--- a/htdocs/product/inventory/tpl/inventory.tpl.php
+++ /dev/null
@@ -1,14 +0,0 @@
-
-
-
-TODO...
-
diff --git a/htdocs/product/reassortlot.php b/htdocs/product/reassortlot.php
index 5d44f37b910..b63a891973c 100644
--- a/htdocs/product/reassortlot.php
+++ b/htdocs/product/reassortlot.php
@@ -118,7 +118,7 @@ $title=$langs->trans("ProductsAndServices");
$sql = 'SELECT p.rowid, p.ref, p.label, p.barcode, p.price, p.price_ttc, p.price_base_type, p.entity,';
$sql.= ' p.fk_product_type, p.tms as datem,';
-$sql.= ' p.duration, p.tosell as statut, p.tobuy, p.seuil_stock_alerte, p.desiredstock, p.stock, p.tobatch,';
+$sql.= ' p.duration, p.tosell as statut, p.tobuy, p.seuil_stock_alerte, p.desiredstock, p.stock, p.tosell, p.tobuy, p.tobatch,';
$sql.= ' ps.fk_entrepot,';
$sql.= ' e.ref as warehouse_ref, e.lieu as warehouse_lieu, e.fk_parent as warehouse_parent,';
$sql.= ' pb.batch, pb.eatby as oldeatby, pb.sellby as oldsellby,';
@@ -160,7 +160,7 @@ if ($search_warehouse) $sql .= natural_search("e.ref", $search_warehouse);
if ($search_batch) $sql .= natural_search("pb.batch", $search_batch);
$sql.= " GROUP BY p.rowid, p.ref, p.label, p.barcode, p.price, p.price_ttc, p.price_base_type, p.entity,";
$sql.= " p.fk_product_type, p.tms,";
-$sql.= " p.duration, p.tosell, p.tobuy, p.seuil_stock_alerte, p.desiredstock, p.stock, p.tobatch,";
+$sql.= " p.duration, p.tosell, p.tobuy, p.seuil_stock_alerte, p.desiredstock, p.stock, p.tosell, p.tobuy, p.tobatch,";
$sql.= " ps.fk_entrepot,";
$sql.= " e.ref, e.lieu, e.fk_parent,";
$sql.= " pb.batch, pb.eatby, pb.sellby,";
@@ -206,21 +206,21 @@ if ($resql)
$texte.=' ('.$langs->trans("StocksByLotSerial").')';
$param='';
- if ($limit > 0 && $limit != $conf->liste_limit) $param.='&limit='.$limit;
- if ($sall) $param.="&sall=".$sall;
- if ($tosell) $param.="&tosell=".$tosell;
- if ($tobuy) $param.="&tobuy=".$tobuy;
- if ($type) $param.="&type=".$type;
- if ($fourn_id) $param.="&fourn_id=".$fourn_id;
- if ($snom) $param.="&snom=".$snom;
- if ($sref) $param.="&sref=".$sref;
- if ($search_batch) $param.="&search_batch=".$search_batch;
- if ($sbarcode) $param.="&sbarcode=".$sbarcode;
- if ($search_warehouse) $param.="&search_warehouse=".$search_warehouse;
- if ($catid) $param.="&catid=".$catid;
- if ($toolowstock) $param.="&toolowstock=".$toolowstock;
- if ($search_sale) $param.="&search_sale=".$search_sale;
- if ($search_categ) $param.="&search_categ=".$search_categ;
+ if ($limit > 0 && $limit != $conf->liste_limit) $param.='&limit='.urlencode($limit);
+ if ($sall) $param.="&sall=".urlencode($sall);
+ if ($tosell) $param.="&tosell=".urlencode($tosell);
+ if ($tobuy) $param.="&tobuy=".urlencode($tobuy);
+ if ($type) $param.="&type=".urlencode($type);
+ if ($fourn_id) $param.="&fourn_id=".urlencode($fourn_id);
+ if ($snom) $param.="&snom=".urlencode($snom);
+ if ($sref) $param.="&sref=".urlencode($sref);
+ if ($search_batch) $param.="&search_batch=".urlencode($search_batch);
+ if ($sbarcode) $param.="&sbarcode=".urlencode($sbarcode);
+ if ($search_warehouse) $param.="&search_warehouse=".urlencode($search_warehouse);
+ if ($catid) $param.="&catid=".urlencode($catid);
+ if ($toolowstock) $param.="&toolowstock=".urlencode($toolowstock);
+ if ($search_sale) $param.="&search_sale=".urlencode($search_sale);
+ if ($search_categ) $param.="&search_categ=".urlencode($search_categ);
/*if ($eatby) $param.="&eatby=".$eatby;
if ($sellby) $param.="&sellby=".$sellby;*/
@@ -349,6 +349,8 @@ if ($resql)
$product_static->label = $objp->label;
$product_static->type=$objp->fk_product_type;
$product_static->entity=$objp->entity;
+ $product_static->status=$objp->tosell;
+ $product_static->status_buy=$objp->tobuy;
$product_static->status_batch=$objp->tobatch;
$product_lot_static->batch=$objp->batch;
diff --git a/htdocs/product/stock/class/entrepot.class.php b/htdocs/product/stock/class/entrepot.class.php
index a3a97984ce9..ab3dfde9bf0 100644
--- a/htdocs/product/stock/class/entrepot.class.php
+++ b/htdocs/product/stock/class/entrepot.class.php
@@ -701,10 +701,12 @@ class Entrepot extends CommonObject
$label = '' . $langs->trans("ShowWarehouse").' ';
$label.= '' . $langs->trans('Ref') . ': ' . (empty($this->ref)?(empty($this->label)?$this->libelle:$this->label):$this->ref);
- if (! empty($this->lieu))
+ if (! empty($this->lieu)) {
$label.= '' . $langs->trans('LocationSummary').': '.$this->lieu;
- if (isset($this->statut))
+ }
+ if (isset($this->statut)) {
$label.= '' . $langs->trans("Status").": ".$this->getLibStatut(5);
+ }
$url = DOL_URL_ROOT.'/product/stock/card.php?id='.$this->id;
diff --git a/htdocs/product/stock/movement_list.php b/htdocs/product/stock/movement_list.php
index 1c7862f10f0..dea7580aeb7 100644
--- a/htdocs/product/stock/movement_list.php
+++ b/htdocs/product/stock/movement_list.php
@@ -195,12 +195,12 @@ if ($action == "correct_stock")
if ($product->hasbatch())
{
- $batch = GETPOST('batch_number');
+ $batch = GETPOST('batch_number', 'alphanohtml');
//$eatby=GETPOST('eatby');
//$sellby=GETPOST('sellby');
- $eatby = dol_mktime(0, 0, 0, GETPOST('eatbymonth'), GETPOST('eatbyday'), GETPOST('eatbyyear'));
- $sellby = dol_mktime(0, 0, 0, GETPOST('sellbymonth'), GETPOST('sellbyday'), GETPOST('sellbyyear'));
+ $eatby = dol_mktime(0, 0, 0, GETPOST('eatbymonth', 'int'), GETPOST('eatbyday', 'int'), GETPOST('eatbyyear', 'int'));
+ $sellby = dol_mktime(0, 0, 0, GETPOST('sellbymonth', 'int'), GETPOST('sellbyday', 'int'), GETPOST('sellbyyear', 'int'));
$result = $product->correct_stock_batch(
$user,
@@ -210,7 +210,7 @@ if ($action == "correct_stock")
GETPOST("label", 'san_alpha'),
GETPOST('unitprice'),
$eatby, $sellby, $batch,
- GETPOST('inventorycode'),
+ GETPOST('inventorycode', 'alphanohtml'),
$origin_element,
$origin_id
); // We do not change value of stock for a correction
@@ -224,7 +224,7 @@ if ($action == "correct_stock")
GETPOST("mouvement"),
GETPOST("label", 'san_alpha'),
GETPOST('unitprice'),
- GETPOST('inventorycode'),
+ GETPOST('inventorycode', 'alphanohtml'),
$origin_element,
$origin_id
); // We do not change value of stock for a correction
@@ -329,7 +329,7 @@ if ($action == "transfert_stock" && !$cancel)
else
{
$srcwarehouseid = $id;
- $batch = GETPOST('batch_number');
+ $batch = GETPOST('batch_number', 'alphanohtml');
$eatby = $d_eatby;
$sellby = $d_sellby;
}
@@ -356,7 +356,7 @@ if ($action == "transfert_stock" && !$cancel)
GETPOST("label", 'san_alpha'),
$pricedest,
$eatby, $sellby, $batch,
- GETPOST('inventorycode')
+ GETPOST('inventorycode', 'alphanohtml')
);
}
}
@@ -368,9 +368,9 @@ if ($action == "transfert_stock" && !$cancel)
$id,
GETPOST("nbpiece"),
1,
- GETPOST("label"),
+ GETPOST("label", 'san_alpha'),
$pricesrc,
- GETPOST('inventorycode')
+ GETPOST('inventorycode', 'alphanohtml')
);
// Add stock
@@ -379,9 +379,9 @@ if ($action == "transfert_stock" && !$cancel)
GETPOST("id_entrepot_destination"),
GETPOST("nbpiece"),
0,
- GETPOST("label"),
+ GETPOST("label", 'san_alpha'),
$pricedest,
- GETPOST('inventorycode')
+ GETPOST('inventorycode', 'alphanohtml')
);
}
if (!$error && $result1 >= 0 && $result2 >= 0)
@@ -424,7 +424,7 @@ $formother = new FormOther($db);
$formproduct = new FormProduct($db);
if (!empty($conf->projet->enabled)) $formproject = new FormProjets($db);
-$sql = "SELECT p.rowid, p.ref as product_ref, p.label as produit, p.tobatch, p.fk_product_type as type, p.entity,";
+$sql = "SELECT p.rowid, p.ref as product_ref, p.label as produit, p.tosell, p.tobuy, p.tobatch, p.fk_product_type as type, p.entity,";
$sql .= " e.ref as warehouse_ref, e.rowid as entrepot_id, e.lieu, e.fk_parent, e.statut,";
$sql .= " m.rowid as mid, m.value as qty, m.datem, m.fk_user_author, m.label, m.inventorycode, m.fk_origin, m.origintype,";
$sql .= " m.batch, m.price,";
@@ -976,6 +976,8 @@ if ($resql)
$productstatic->label = $objp->produit;
$productstatic->type = $objp->type;
$productstatic->entity = $objp->entity;
+ $productstatic->status = $objp->tosell;
+ $productstatic->status_buy = $objp->tobuy;
$productstatic->status_batch = $objp->tobatch;
$productlot->id = $objp->lotid;
diff --git a/htdocs/product/stock/productlot_list.php b/htdocs/product/stock/productlot_list.php
index 4f851d8e1de..527afee2607 100644
--- a/htdocs/product/stock/productlot_list.php
+++ b/htdocs/product/stock/productlot_list.php
@@ -214,6 +214,8 @@ $sql.= " t.import_key,";
$sql.= " p.fk_product_type as product_type,";
$sql.= " p.ref as product_ref,";
$sql.= " p.label as product_label,";
+$sql.= " p.tosell,";
+$sql.= " p.tobuy,";
$sql.= " p.tobatch";
// Add fields for extrafields
if (! empty($extrafields->attributes[$object->table_element]['label'])) {
@@ -300,7 +302,7 @@ if ($resql)
print ' ';
print ' ';
- print_barre_liste($title, $page, $_SERVER["PHP_SELF"], $param, $sortfield, $sortorder, '', $num, $nbtotalofrecords, 'products', 0, '', '', $limit);
+ print_barre_liste($title, $page, $_SERVER["PHP_SELF"], $param, $sortfield, $sortorder, '', $num, $nbtotalofrecords, 'barcode', 0, '', '', $limit);
$topicmail = "Information";
$modelmail = "productlot";
@@ -418,6 +420,7 @@ if ($resql)
if ($obj)
{
$productlot->id = $obj->rowid;
+ $productlot->status = $obj->tosell;
$productlot->batch = $obj->batch;
// You can use here results
@@ -438,7 +441,10 @@ if ($resql)
$productstatic->type = $obj->product_type;
$productstatic->ref = $obj->product_ref;
$productstatic->label = $obj->product_label;
+ $productstatic->status = $obj->tosell;
+ $productstatic->status_buy = $obj->tobuy;
$productstatic->status_batch = $obj->tobatch;
+
print ''.$productstatic->getNomUrl(1).' ';
if (!$i) $totalarray['nbfield']++;
}
diff --git a/htdocs/resource/card.php b/htdocs/resource/card.php
index 975dd564a31..152a572a737 100644
--- a/htdocs/resource/card.php
+++ b/htdocs/resource/card.php
@@ -306,7 +306,7 @@ if ($action == 'create' || $object->fetch($id, $ref) > 0)
print $formconfirm;
- $linkback = ''.$langs->trans("BackToList").' ';
+ $linkback = ''.$langs->trans("BackToList").' ';
$morehtmlref = '';
diff --git a/htdocs/supplier_proposal/card.php b/htdocs/supplier_proposal/card.php
index b8f607cfc20..f01ad4c0b1b 100644
--- a/htdocs/supplier_proposal/card.php
+++ b/htdocs/supplier_proposal/card.php
@@ -229,7 +229,7 @@ if (empty($reshook))
dol_print_error($db, $object->error);
}
- // Create askprice
+ // Create supplier proposal
elseif ($action == 'add' && $user->rights->supplier_proposal->creer)
{
$object->socid = $socid;
@@ -630,7 +630,7 @@ if (empty($reshook))
elseif (GETPOST('idprodfournprice', 'alpha') > 0)
{
//$qtytosearch=$qty; // Just to see if a price exists for the quantity. Not used to found vat.
- $qtytosearch = -1; // We force qty to -1 to be sure to find if a supplier price exist
+ $qtytosearch = -1; // We force qty to -1 to be sure to find if the supplier price that exists
$idprod = $productsupplier->get_buyprice(GETPOST('idprodfournprice', 'alpha'), $qtytosearch);
$res = $productsupplier->fetch($idprod);
}
@@ -660,7 +660,8 @@ if (empty($reshook))
$pu_ht = $productsupplier->fourn_pu;
if (empty($pu_ht)) $pu_ht = 0; // If pu is '' or null, we force to have a numeric value
- $fournprice = 0;
+ // If GETPOST('idprodfournprice') is a numeric, we can use it. If it is empty or if it is 'idprod_123', we should use -1 (not used)
+ $fournprice = (is_numeric(GETPOST('idprodfournprice', 'alpha')) ? GETPOST('idprodfournprice', 'alpha') : -1);
$buyingprice = 0;
$result = $object->addline(
diff --git a/htdocs/supplier_proposal/class/supplier_proposal.class.php b/htdocs/supplier_proposal/class/supplier_proposal.class.php
index 8848df02e80..3c62e45ffbd 100644
--- a/htdocs/supplier_proposal/class/supplier_proposal.class.php
+++ b/htdocs/supplier_proposal/class/supplier_proposal.class.php
@@ -388,7 +388,7 @@ class SupplierProposal extends CommonObject
* @param int $rang Position of line
* @param int $special_code Special code (also used by externals modules!)
* @param int $fk_parent_line Id of parent line
- * @param int $fk_fournprice Id supplier price
+ * @param int $fk_fournprice Id supplier price. If 0, we will take best price. If -1 we keep it empty.
* @param int $pa_ht Buying price without tax
* @param string $label ???
* @param array $array_option extrafields array
@@ -583,15 +583,16 @@ class SupplierProposal extends CommonObject
// infos marge
if (!empty($fk_product) && empty($fk_fournprice) && empty($pa_ht)) {
- // by external module, take lowest buying price
+ // When fk_fournprice is 0, we take the lowest buying price
include_once DOL_DOCUMENT_ROOT.'/fourn/class/fournisseur.product.class.php';
$productFournisseur = new ProductFournisseur($this->db);
$productFournisseur->find_min_price_product_fournisseur($fk_product);
$this->line->fk_fournprice = $productFournisseur->product_fourn_price_id;
} else {
- $this->line->fk_fournprice = $fk_fournprice;
+ $this->line->fk_fournprice = ($fk_fournprice > 0 ? $fk_fournprice : 0); // If fk_fournprice is -1, we will not use fk_fournprice
}
$this->line->pa_ht = $pa_ht;
+ //var_dump($this->line->fk_fournprice);exit;
// Multicurrency
$this->line->fk_multicurrency = $this->fk_multicurrency;
diff --git a/htdocs/variants/card.php b/htdocs/variants/card.php
index 9f3deb9e93f..5dd3521b4e1 100644
--- a/htdocs/variants/card.php
+++ b/htdocs/variants/card.php
@@ -148,9 +148,9 @@ if ($action != 'edit') {
print '
diff --git a/htdocs/resource/class/dolresource.class.php b/htdocs/resource/class/dolresource.class.php
index 2b3b0613092..7e2f11e1bf5 100644
--- a/htdocs/resource/class/dolresource.class.php
+++ b/htdocs/resource/class/dolresource.class.php
@@ -938,29 +938,58 @@ class Dolresource extends CommonObject
/**
* Return clicable link of object (with eventually picto)
*
* @param int $withpicto Add picto into link
* @param string $option Where point the link ('compta', 'expedition', 'document', ...)
* @param string $get_params Parametres added to url
* @param int $notooltip 1=Disable tooltip
* @return string String with URL
*/
- public function getNomUrl($withpicto = 0, $option = '', $get_params = '', $notooltip = 0)
+ public function getNomUrl($withpicto = 0, $option = '', $get_params = '', $notooltip = 0, $morecss = '', $save_lastsearch_value = -1)
{
global $langs;
$result = '';
- $label = $langs->trans("ShowResource").': '.$this->ref;
-
- $linkstart = '';
- $linkend = '';
- if ($option == '')
- {
- $linkstart = '
';
- $picto = 'resource';
- $label = $langs->trans("ShowResource").': '.$this->ref;
- $linkend = ' ';
+ $label = '
'.$langs->trans("ShowResource").' ';
+ $label .= '
';
+ $label .= '
'.$langs->trans('Ref').': '.$this->ref;
+ /*if (isset($this->status)) {
+ $label.= '
' . $langs->trans("Status").": ".$this->getLibStatut(5);
+ }*/
+ if (isset($this->type_label)) {
+ $label.= '
' . $langs->trans("ResourceType").": ".$this->type_label;
}
+ $url = DOL_URL_ROOT.'/resource/card.php?id='.$this->id;
+
+ if ($option != 'nolink')
+ {
+ // Add param to save lastsearch_values or not
+ $add_save_lastsearch_values = ($save_lastsearch_value == 1 ? 1 : 0);
+ if ($save_lastsearch_value == -1 && preg_match('/list\.php/', $_SERVER["PHP_SELF"])) $add_save_lastsearch_values = 1;
+ if ($add_save_lastsearch_values) $url .= '&save_lastsearch_values=1';
+ }
+
+ $linkclose = '';
+ if (empty($notooltip))
+ {
+ if (!empty($conf->global->MAIN_OPTIMIZEFORTEXTBROWSER))
+ {
+ $label = $langs->trans("ShowMyObject");
+ $linkclose .= ' alt="'.dol_escape_htmltag($label, 1).'"';
+ }
+ $linkclose .= ' title="'.dol_escape_htmltag($label, 1).'"';
+ $linkclose .= ' class="classfortooltip'.($morecss ? ' '.$morecss : '').'"';
+ }
+ else $linkclose = ($morecss ? ' class="'.$morecss.'"' : '');
+
+ $linkstart = '
';
+ $linkend = ' ';
+ /*$linkstart = '
';
+ $linkend = ' ';*/
+
$result .= $linkstart;
if ($withpicto) $result .= img_object(($notooltip ? '' : $label), ($this->picto ? $this->picto : 'generic'), ($notooltip ? (($withpicto != 2) ? 'class="paddingright"' : '') : 'class="'.(($withpicto != 2) ? 'paddingright ' : '').'classfortooltip"'), 0, 0, $notooltip ? 0 : 1);
if ($withpicto != 2) $result .= $this->ref;
@@ -938,29 +938,58 @@ class Dolresource extends CommonObject
* Return clicable link of object (with eventually picto)
*
- * @param int $withpicto Add picto into link
- * @param string $option Where point the link ('compta', 'expedition', 'document', ...)
- * @param string $get_params Parametres added to url
- * @param int $notooltip 1=Disable tooltip
- * @return string String with URL
+ * @param int $withpicto Add picto into link
+ * @param string $option Where point the link ('compta', 'expedition', 'document', ...)
+ * @param string $get_params Parametres added to url
+ * @param int $notooltip 1=Disable tooltip
+ * @param string $morecss Add more css on link
+ * @param int $save_lastsearch_value -1=Auto, 0=No save of lastsearch_values when clicking, 1=Save lastsearch_values whenclicking
+ * @return string String with URL
*/